@@ -346,6 +346,60 @@ class SequencesAPI(APIClient):
                 >>> c = CogniteClient()
                 >>> my_update = SequenceUpdate(id=1).description.set("New description").metadata.add({"key": "value"})
                 >>> res = c.sequences.update(my_update)
+
+        Updating column definitions:
+
+            Currently, updating the column definitions of a sequence is only supported through partial update, using `add`, `remove` and `modify` methods on the `columns` property.
+
+            Add a single new column::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import SequenceUpdate
+                >>> c = CogniteClient()
+                >>>
+                >>> my_update = SequenceUpdate(id=1).columns.add({"valueType":"STRING","externalId":"user","description":"some description"})
+                >>> res = c.sequences.update(my_update)
+
+            Add multiple new columns::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import SequenceUpdate
+                >>> c = CogniteClient()
+                >>>
+                >>> column_def = [{"valueType":"STRING","externalId":"user","description":"some description"}, {"valueType":"DOUBLE","externalId":"amount"}]
+                >>> my_update = SequenceUpdate(id=1).columns.add(column_def)
+                >>> res = c.sequences.update(my_update)
+
+            Remove a single column::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import SequenceUpdate
+                >>> c = CogniteClient()
+                >>>
+                >>> my_update = SequenceUpdate(id=1).columns.remove("col_external_id1")
+                >>> res = c.sequences.update(my_update)
+
+            Remove multiple columns::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import SequenceUpdate
+                >>> c = CogniteClient()
+                >>>
+                >>> my_update = SequenceUpdate(id=1).columns.remove(["col_external_id1","col_external_id2"])
+                >>> res = c.sequences.update(my_update)
+
+            Update existing columns::
+
+                >>> from cognite.client import CogniteClient
+                >>> from cognite.client.data_classes import SequenceUpdate, SequenceColumnUpdate
+                >>> c = CogniteClient()
+                >>>
+                >>> column_updates = [\
+                      SequenceColumnUpdate(external_id="col_external_id_1").external_id.set("new_col_external_id"),\
+                      SequenceColumnUpdate(external_id="col_external_id_2").description.set("my new description"),\
+                    ]
+                >>> my_update = SequenceUpdate(id=1).columns.modify(column_updates)
+                >>> res = c.sequences.update(my_update)
         """
         return self._update_multiple(items=item)
 
@@ -553,7 +607,8 @@ class SequencesDataAPI(APIClient):
         post_obj.update(self._process_columns(column_external_ids=[sequence.column_external_ids[0]]))
         post_obj.update({"start": start, "end": end})
         for data, _ in self._fetch_data(post_obj):
-            self.delete(rows=[r["rowNumber"] for r in data], external_id=external_id, id=id)
+            if data:
+                self.delete(rows=[r["rowNumber"] for r in data], external_id=external_id, id=id)
 
     def retrieve(
         self,
