@@ -1,3 +1,9 @@
+from cognite.client.data_classes.annotations import (  # isort: skip
+    Annotation,
+    AnnotationFilter,
+    AnnotationList,
+    AnnotationUpdate,
+)
 from cognite.client.data_classes.assets import (
     AggregateResultItem,
     Asset,
@@ -31,10 +37,6 @@ from cognite.client.data_classes.files import (
     FileMetadataFilter,
     FileMetadataList,
     FileMetadataUpdate,
-    GeoLocation,
-    GeoLocationFilter,
-    Geometry,
-    GeometryFilter,
 )
 from cognite.client.data_classes.iam import (
     APIKey,
@@ -71,12 +73,15 @@ from cognite.client.data_classes.sequences import (
 )
 from cognite.client.data_classes.templates import (
     ConstantResolver,
+    Source,
     TemplateGroup,
     TemplateGroupList,
     TemplateGroupVersion,
     TemplateGroupVersionList,
     TemplateInstance,
     TemplateInstanceList,
+    View,
+    ViewResolver,
 )
 from cognite.client.data_classes.three_d import (
     BoundingBox3D,
@@ -140,10 +145,13 @@ from cognite.client.data_classes.data_sets import (  # isort: skip
     DataSetUpdate,
 )
 
-
 from cognite.client.data_classes.shared import (  # isort: skip
     AggregateResult,
     AggregateUniqueValuesResult,
+    GeoLocation,
+    GeoLocationFilter,
+    Geometry,
+    GeometryFilter,
     TimestampRange,
 )
 
