@@ -1,9 +1,8 @@
 import threading
-from typing import *
 
 from cognite.client.data_classes._base import *
-from cognite.client.data_classes.labels import Label, LabelFilter
-from cognite.client.data_classes.shared import TimestampRange
+from cognite.client.data_classes.labels import Label, LabelDefinition, LabelFilter
+from cognite.client.data_classes.shared import GeoLocation, GeoLocationFilter, TimestampRange
 
 
 class AssetAggregate(dict):
@@ -53,6 +52,7 @@ class Asset(CogniteResource):
         metadata (Dict[str, str]): Custom, application specific metadata. String key -> String value. Limits: Maximum length of key is 128 bytes, value 10240 bytes, up to 256 key-value pairs, of total size at most 10240.
         source (str): The source of the asset.
         labels (List[Label]): A list of the labels associated with this resource item.
+        geo_location (GeoLocation): The geographic metadata of the asset.
         id (int): A server-generated ID for the object.
         created_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
         last_updated_time (int): The number of milliseconds since 00:00:00 Thursday, 1 January 1970, Coordinated Universal Time (UTC), minus leap seconds.
@@ -71,7 +71,8 @@ class Asset(CogniteResource):
         data_set_id: int = None,
         metadata: Dict[str, str] = None,
         source: str = None,
-        labels: List[Label] = None,
+        labels: List[Union[Label, str, LabelDefinition]] = None,
+        geo_location: GeoLocation = None,
         id: int = None,
         created_time: int = None,
         last_updated_time: int = None,
@@ -79,8 +80,8 @@ class Asset(CogniteResource):
         aggregates: Union[Dict[str, Any], AggregateResultItem] = None,
         cognite_client=None,
     ):
-        if labels is not None and len(labels) > 0 and not all(isinstance(l, Label) for l in labels):
-            raise TypeError("Asset.labels should be of type List[Label]")
+        if geo_location is not None and not isinstance(geo_location, GeoLocation):
+            raise TypeError("Asset.geo_location should be of type GeoLocation")
         self.external_id = external_id
         self.name = name
         self.parent_id = parent_id
@@ -89,7 +90,8 @@ class Asset(CogniteResource):
         self.data_set_id = data_set_id
         self.metadata = metadata
         self.source = source
-        self.labels = labels
+        self.labels = Label._load_list(labels)
+        self.geo_location = geo_location
         self.id = id
         self.created_time = created_time
         self.last_updated_time = last_updated_time
@@ -103,8 +105,9 @@ class Asset(CogniteResource):
         if isinstance(resource, Dict):
             if instance.aggregates is not None:
                 instance.aggregates = AggregateResultItem(**instance.aggregates)
-        if instance.labels is not None:
-            instance.labels = [Label._load(label) for label in instance.labels]
+        instance.labels = Label._load_list(instance.labels)
+        if instance.geo_location is not None:
+            instance.geo_location = GeoLocation._load(instance.geo_location)
         return instance
 
     def __hash__(self):
@@ -227,6 +230,9 @@ class AssetUpdate(CogniteUpdate):
             return self._remove(value)
 
     class _LabelAssetUpdate(CogniteLabelUpdate):
+        def set(self, value: Union[str, List[str]]) -> "AssetUpdate":
+            return self._set(value)
+
         def add(self, value: Union[str, List[str]]) -> "AssetUpdate":
             return self._add(value)
 
@@ -269,6 +275,10 @@ class AssetUpdate(CogniteUpdate):
     def labels(self):
         return AssetUpdate._LabelAssetUpdate(self, "labels")
 
+    @property
+    def geo_location(self):
+        return AssetUpdate._PrimitiveAssetUpdate(self, "geoLocation")
+
 
 class AssetList(CogniteResourceList):
     _RESOURCE = Asset
@@ -362,6 +372,7 @@ class AssetFilter(CogniteFilter):
         root (bool): Whether the filtered assets are root assets, or not. Set to True to only list root assets.
         external_id_prefix (str): Filter by this (case-sensitive) prefix for the external ID.
         labels (LabelFilter): Return only the resource matching the specified label constraints.
+        geo_location (GeoLocationFilter): Only include files matching the specified geographic relation.
         cognite_client (CogniteClient): The client to associate with this object.
     """
 
@@ -380,6 +391,7 @@ class AssetFilter(CogniteFilter):
         root: bool = None,
         external_id_prefix: str = None,
         labels: LabelFilter = None,
+        geo_location: GeoLocationFilter = None,
         cognite_client=None,
     ):
         self.name = name
@@ -395,6 +407,7 @@ class AssetFilter(CogniteFilter):
         self.root = root
         self.external_id_prefix = external_id_prefix
         self.labels = labels
+        self.geo_location = geo_location
         self._cognite_client = cognite_client
 
         if labels is not None and not isinstance(labels, LabelFilter):
